cmoncrawl.processor.pipeline.downloader
=======================================

.. automodule:: cmoncrawl.processor.pipeline.downloader

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      log_after_retry
   
   

   
   
   .. rubric:: Classes

   .. autoclass:: AsyncDownloader
      :members:

   .. autoclass:: DownloaderLocalFiles
      :members:

   .. autoclass:: DummyDownloader
      :members:

   .. autoclass:: IDownloader
      :members:

   .. autoclass:: WarcIterator
      :members:


   
   
   



